@@ -195,7 +195,9 @@ def InitStartMeasurement():
     data.Note=""
     
     for i in range(0, data.arrDataLen): #clear data of old records
-        for j in range(0,  6): data.arrData[j][i]=0
+        for j in range(0,  4): 
+            data.arrData[j][i]=0
+        data.arrData[5][i]=""
     
     if(data.QuickMode==0):
         data.interval=data.sampling #normal
@@ -880,9 +882,12 @@ class frmViewWindow(QMainWindow):
             
                         
         GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        MaxGraphStart=max(data.arrDataIndex-data.arrXscale[data.Xscale]*775, 0)
+        data.GraphStart=min(MaxGraphStart,  data.GraphStart)
+#        print GraphLen,  data.arrDataIndex,  data.arrXscale[data.Xscale],  data.GraphStart,  MaxGraphStart
 #        data.GraphStart=min(data.GraphStart+360, max(GraphLen-775, 0))
 #        print data.GraphStart
-        if(data.GraphStart<max(GraphLen-779, 0)): self.ui.bRight.setEnabled(True)
+        if(data.GraphStart<MaxGraphStart): self.ui.bRight.setEnabled(True)
         else: self.ui.bRight.setEnabled(False)
         if(data.GraphStart>0): self.ui.bLeft.setEnabled(True)
         else: self.ui.bLeft.setEnabled(False)
@@ -906,9 +911,12 @@ class frmViewWindow(QMainWindow):
         LoadFileList()
         ProcessData(True)
         data.Xscale=1 #default zoom level
-#        data.GraphStart=0        
-        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(GraphLen-779, 0)
+        
+        MaxGraphStart=data.arrDataIndex-data.arrXscale[data.Xscale]*775
+        data.GraphStart=min(MaxGraphStart,  data.arrDataIndex-775)
+        data.GraphStart=max(data.GraphStart,  0)
+#        print "data.GraphStart:",  data.GraphStart,  data.arrDataIndex
+        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindowGraph.show()
@@ -937,10 +945,14 @@ class frmViewWindow(QMainWindow):
         self.ui.bZoomOut.setEnabled(True)
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
-#        data.GraphStart=0
-        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        
+        MaxGraphStart=data.arrDataIndex-data.arrXscale[data.Xscale]*775
+        data.GraphStart=min(MaxGraphStart,  data.arrDataIndex-775)
+        data.GraphStart=max(data.GraphStart,  0)        
+#        print "data.GraphStart:",  data.GraphStart,  data.arrDataIndex
+        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-        data.GraphStart=max(GraphLen-779, 0)
+#        data.GraphStart=max(GraphLen-779, 0)
         self.update()
         self.UpdateScreen()
 
@@ -950,9 +962,12 @@ class frmViewWindow(QMainWindow):
         self.ui.bZoomIn.setEnabled(True)
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
-#        data.GraphStart=0
-        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(GraphLen-779, 0)
+        
+        MaxGraphStart=data.arrDataIndex-data.arrXscale[data.Xscale]*775
+        data.GraphStart=min(MaxGraphStart,  data.arrDataIndex-775)
+        data.GraphStart=max(data.GraphStart,  0)
+#        print "data.GraphStart:",  data.GraphStart,  data.arrDataIndex
+        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
@@ -986,8 +1001,16 @@ class frmViewWindow(QMainWindow):
         
     def goRight(self):
         Show_passed_time("Scroll right",   1)
+#        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+#        print "GraphLen:",  GraphLen
+#        data.GraphStart=min(data.GraphStart+600, max(GraphLen-779, 0))
+#        data.GraphStart=data.GraphStart+600
+        
         GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=min(data.GraphStart+600, max(GraphLen-779, 0))
+        MaxGraphStart=max(data.arrDataIndex-data.arrXscale[data.Xscale]*775, 0)
+#        MaxGraphStart=data.arrDataIndex-data.arrXscale[data.Xscale]*775
+        data.GraphStart=min(MaxGraphStart,  data.GraphStart+600)
+
 #        print data.GraphStart        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
