@@ -74,7 +74,23 @@ def WriteIntoLogFile():
 #  Close log file
 ###########################################################################
 def StopLogfile():    
+#    print "Scan in",  data.arrDataIndex,  "...",  data.arrDataLen-1,  "for events"
+    for lastIndex in range(data.arrDataLen-1,  data.arrDataIndex,  -1):
+#        print lastIndex,  data.arrData[5][lastIndex]
+        if(data.arrData[5][lastIndex]!=""): #found an event note, write file until here
+#            print "Found last event note on index:",  lastIndex
+            for i in range(data.arrDataIndex+1,  lastIndex+1):
+#                print i,  data.arrData[5][i]
+                d="0, 0, 0, "+str(data.arrData[5][i])
+                data.logfile.write(d+"\n")
+            data.logfile.close()
+            data.arrDataIndex=lastIndex+1
+            print "Wrote",  i +1,  "records into file"
+            return # break loop
+    
+    print "Wrote",  data.arrDataIndex,  "records into file"
     data.logfile.close()
+    
 
 
 
@@ -253,7 +269,7 @@ def LoadLogFile():
 #  Load log file  to change Note (on line 2)
 ###########################################################################
 def ChangeNoteInFile():    
-#    print "Reopen log file and update note:",  data.Note
+    print "Reopen log file and update note:",  data.Note
     file = open(data.logfolder+data.logfilename, 'w')
     print "Open logfile",  data.logfilename,  ", change Note to \"",  data.Note,  "\" in file",  data.logfilename
 
@@ -264,7 +280,7 @@ def ChangeNoteInFile():
         d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i]) + ", " +  str(data.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    print "Wrote",  i +1,  "lines into file"
+    print "Wrote",  i +1,  "records into file"
     
     
     
