@@ -93,13 +93,15 @@ def GetSensorData():
 ###########################################################################
 #  Process the data, generate movement indication
 ###########################################################################
-def ProcessData():
+def ProcessData(ProcessAll=False):
     #DERIVATION (ABLEITUNG)
     Show_passed_time("ProcessData Start")
 #        print i,  data.arrData[0][i] ,  data.arrData[1][i],  data.arrData[2][i]  
 
     lastmove=0 
-    for i in range(0, data.arrDataIndex-data.derivation):     
+    if(ProcessAll==True): start=0
+    else: start=data.arrDataIndex-data.derivation-1
+    for i in range(start, data.arrDataIndex-data.derivation):     
         t=i*(data.interval*data.value_smoothing)/1000
 #        print t,  data.DelayStartTime,  data.QuickMode
         if(data.QuickMode==1 or t>data.DelayStartTime):
@@ -138,16 +140,17 @@ def showGraph(self,  QtGui):
         paint.begin(self)
 
         paint.setFont(QtGui.QFont('Decorative', 12))
-        paint.setPen(QtGui.QColor("gray"))
+        paint.setPen(QtGui.QColor("white"))
         paint.setBrush(QtGui.QColor("black"))
 
         #show Graph border
-        paint.drawRect(0,0,781,data.Ysize)           
+        paint.drawRect(0,0,781,data.Ysize)                  
 
         Xscale=data.arrXscale[data.Xscale]
 #        print "Zoom level:",  data.Xscale
-        Pixels=data.arrDataIndex/Xscale
-        if(Pixels==0): Pixels=1 #prevent divisions by zero
+        GraphLen=data.arrDataIndex/Xscale
+        if(GraphLen==0): GraphLen=1 #prevent divisions by zero
+#        print "GraphLen:",  GraphLen
             
         try:
             t=string.split(data.arrData[0][data.GraphStart], ":")
@@ -177,7 +180,8 @@ def showGraph(self,  QtGui):
         # ##############################################
         #DRAW main scaling lines + text        
         paint.setPen(QtGui.QColor("white"))
-        if(data.test==0):
+#        if(data.test==0):
+        if(data.QuickMode==0): #normal mode
             for i in range(-1*decade, 781+decade,  decade):
                 paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
                 for k in range(1, 6):
@@ -197,15 +201,15 @@ def showGraph(self,  QtGui):
 
 
         #DRAW scroll bar 
-        start=data.GraphStart
-        end=start+775
-        if(data.debug==1): print start,  "(",  start*100/Pixels, "%)",  end,  "(",  end*100/Pixels, "%)", Pixels
-        if(start>0 or end<Pixels): #only draw if scroll bar needed
+#        start=data.GraphStart
+        end=data.GraphStart+775
+        if(data.debug==1): print data.GraphStart,  "(",  data.GraphStart*100/GraphLen, "%)",  end,  "(",  end*100/GraphLen, "%)", GraphLen
+        if(data.GraphStart>0 or end<GraphLen): #only draw if scroll bar needed
             paint.setPen(QtGui.QColor("gray"))
             paint.drawRect(0,data.Ysize+37,776,7)
             paint.setPen(QtGui.QColor("white"))
             paint.setBrush(QtGui.QColor("white"))
-            paint.drawRect(start*779/Pixels,data.Ysize+38,(end-start)*779/Pixels,5)
+            paint.drawRect(data.GraphStart*779/GraphLen,data.Ysize+38,(end-data.GraphStart)*779/GraphLen,5)
 
         Show_passed_time("showGraph Frame+variouse line/texts done")
 
@@ -232,8 +236,13 @@ def showGraph(self,  QtGui):
                 break
 
         
-        
+        lastdatapoint=data.arrDataIndex
         for p in range(data.GraphStart,  end,  Xscale):
+#            print p,  data.arrData[0][p]
+            if(data.arrData[0][p]=="0"): 
+#                print "break,  reached time with 0:",  p
+                lastdatapoint=p
+                break
             i=p-data.GraphStart
             #when Xscale is small, we have to merge several records into 1 pixel.
             #Too not miss any movement, we use the biggest movement of the merged records:
@@ -242,8 +251,9 @@ def showGraph(self,  QtGui):
                 if(data.arrData[3][p+j]>peak): peak=data.arrData[3][p+j]
 
             paint.drawLine(i/Xscale+1, data.Ysize-peak-1-15, i/Xscale+1, data.Ysize-1-15)  #draw yellow movement bar
-      
-            if(peak>data.trigger): #draw time bar
+
+            #draw time bars
+            if(peak>data.trigger): 
                 x0=lastmove/Xscale+1
                 x1=i/Xscale-1
                 if(x0<=x1):
@@ -262,14 +272,25 @@ def showGraph(self,  QtGui):
                 
           
 
-#        print end-1,  data.arrDataIndex
-        for m in range(end-1,  data.arrDataIndex):    #find first peak after shown graph
-            if(data.arrData[3][m]>data.trigger or m>=data.arrDataIndex-Xscale):
-                i=m
+        #draw last time bar
+#        for m in range(end-1,  data.arrDataIndex):    #find first peak after shown graph
+#        print "Search for end of last time line"
+#        print end-1,  "lastdatapoint:",  lastdatapoint
+#        for m in range(max(end-1, lastdatapoint),  data.arrDataIndex):    #find first peak after shown graph
+        for m in range(end,  data.arrDataIndex):    #find first peak after shown graph
+#            if(data.arrData[0][m]=="0"): 
+##                print "break,  reached time with 0",  p
+##                break
+#                pass
+            if(data.arrData[3][m]>data.trigger or m>=data.arrDataIndex-Xscale or m==lastdatapoint):
                 x0=lastmove/Xscale+1
-                x1=(i-data.derivation)/Xscale-data.GraphStart
-#                print "first time bar end after graph:", x0,  x1,  lastmove,  lastmove+data.GraphStart,  i,   data.arrData[0][lastmove+data.GraphStart],  data.arrData[0][i]
-                if(x0<=x1):
+#                print m,  lastdatapoint
+#                m=min(m,  lastdatapoint)
+#                x1=(m-data.derivation)/Xscale-data.GraphStart
+                x1=min(lastdatapoint/Xscale, (m-data.derivation)/Xscale-data.GraphStart)
+#                print x0,  x1
+#                print "first time bar end after graph:", x0,  x1,  lastmove,  lastmove+data.GraphStart,  m,   data.arrData[0][lastmove+data.GraphStart],  data.arrData[0][i]
+                if(x0<=x1 and x0>=0):
                     t=(x1-x0)*Xscale/6          
                     if(t>30): color="#009100" #green
                     elif(t>15): color="#005000" #dark green
@@ -278,6 +299,7 @@ def showGraph(self,  QtGui):
                     paint.setBrush(QtGui.QColor(color))
                     paint.setPen(QtGui.QColor(color))
                     x1=min(x1,  775) #limit to end of graph
+                    print "draw line",  x0,  "-",  x1
                     paint.drawRect(x0+1, data.Ysize-11, x1-x0, 10)          
                 break
            
@@ -483,11 +505,11 @@ def InitAlarm():
     
     if(i<data.arrDataLen): 
         data.arrData[5][i]="Alarm Time Window End" #Last oportunity for alarm
-#            print "Set Alarm Time Window End:",  i
+        print "Set Alarm Time Window End:",  i
 #            if(i-data.AlarmTimeWindow*6>0):
         i=max(i-6*data.AlarmTimeWindow, 0)
         data.arrData[5][i]="Alarm Time Window Begin" #First oportunity for alarm
-#            print "Set Alarm Time Window Begin:",  i
+        print "Set Alarm Time Window Begin:",  i
     else:
         print "EventSetAlarm is out of range"
         
@@ -499,31 +521,37 @@ def ProcessAlarm():
     i=data.arrDataIndex-data.derivation            
     if(i>1): peak=data.arrData[3][i-1]
     else: peak=0
-#    print "Peak:",  peak,  data.trigger
-    if(peak>data.trigger): #Movement, check if time for alarm        
-        Now=int(strftime("%H", time.localtime()))*60+int(strftime("%M", time.localtime()))
-        Al=int(data.AlarmHour)*60+int(data.AlarmMinute)
+    h=int(strftime("%H", time.localtime()))
+    m=int(strftime("%M", time.localtime()))
+    Now=h*60+m
+    Alarm=int(data.AlarmHour)*60+int(data.AlarmMinute)
+#    print "Peak:",  peak,  data.trigger Al
+    if(peak>data.trigger): #big Movement
+#        Now=int(strftime("%H", time.localtime()))*60+int(strftime("%M", time.localtime()))
+#        Al=int(data.AlarmHour)*60+int(data.AlarmMinute)
 #        print "Now:", Now,  "Alarm:", Al,  "AlarmTimeWindow:", data.AlarmTimeWindow, "AlarmIsSet:", data.AlarmIsSet, "AlarmIsActive:",  data.AlarmIsActive
-        if(data.AlarmIsSet==True and data.AlarmIsActive==False and  Now>(Al-data.AlarmTimeWindow) and Now<=Al): #set Alarm off
+        if(data.AlarmIsSet==True and data.AlarmIsActive==False and  Now>(Alarm-data.AlarmTimeWindow) and Now<=Alarm): #We are in alarm time window and alarm is set and not active yet
             print "************ ALARM ALARM *********************"
             data.AlarmIsActive=True
 #            print "Mark alarm in array on index:",  data.arrDataIndex-1
-            data.arrData[5][data.arrDataIndex-1]="Alarm"      
-#            print "Add Alarm to array on index:",  data.arrDataIndex-1
-            h=int(strftime("%H", time.localtime())) #set new alarm to go off now
-            m=int(strftime("%M", time.localtime()))
-#            if(data.demo==0): # we are on a N900
+            if(data.arrData[5][data.arrDataIndex-1]==0): data.arrData[5][data.arrDataIndex-1]="Alarm"    
+            else: data.arrData[5][data.arrDataIndex-2]="Alarm"    
             DeleteAlarm() #delete old alarm if existing
             print "* Set new Alarm to current time:",  h,  ":",  m
             SetAlarm(h,  m) #set alarm to go off now
-#            else: 
-#                print "Can not set alarm off, Maemo interface not available"
-            return 1
-    else: return 0
-    
+#            return 1
+    elif(Now==Alarm): #End of alarm time window, set alarm off anyway
+        if(data.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
+            print "************ ALARM ALARM *********************"
+            data.AlarmIsActive=True
+            if(data.arrData[5][data.arrDataIndex-1]==0): data.arrData[5][data.arrDataIndex-1]="Alarm"    
+            else: data.arrData[5][data.arrDataIndex-2]="Alarm"    
+#            return 1
+#    else: return 0
     
     
     
     
     
+
     
